// file: $USFS/class/image_analysis/v1.0/imaga_hist_01.cc
//

// isip include files
//
#include "image_analysis.h"

#include "image_analysis_constants.h"
#include <integral_constants.h>

// method: hist_test_cc
//
// arguments:
//  float_8& sbe_a: (output) the image's sbe value
//  char_1* image_fname_a: (input) the image's filename
//
// return: a logical_1 value indicating the status
//
// this method computes a histogram and compares it to the reference model.
//
logical_1 Image_analysis::hist_test_cc(float_8& sbe_a,
				       char_1* image_fname_a) {
 
  // initialize
  //
  if (hist_init_cc() == ISIP_FALSE) {
    error_handler_cc((char_1*)"hist_test_cc",
		     (char_1*)"error while initializing the histogram");
    return ISIP_FALSE;
  }
  
  // compute a histogram
  //
  if (hist_compute_cc(image_fname_a) == ISIP_FALSE) {
    error_handler_cc((char_1*)"hist_test_cc",
		     (char_1*)"error while computing the histogram");
    return ISIP_FALSE;
  }
  // normalize
  //
  if (hist_normalize_cc() == ISIP_FALSE) {
    error_handler_cc((char_1*)"hist_test_cc",
		     (char_1*)"error while normalizing the histogram");
    return ISIP_FALSE;
  }
  
  // provide some debugging information
  //
  if (debug_level_d > ISIP_DEBUG_BRIEF) {
    fprintf(stdout, "<%s> %s = %ld\n", "Image_analysis::hist_compute_cc",
	    "hist_t_npxls", hist_t_npxls_d);
    fprintf(stdout, "<%s> %s = %ld\n", "Image_analysis::hist_compute_cc",
	    "hist_t_nimages_d", hist_t_nimages_d);
  
    // display the histogram
    //
    fprintf(stdout, "red pdf:\n");
    for (int_4 i=0; i<hist_nbins_d; i++) {
      fprintf(stdout, "%ld %ld: %f\n", hist_redp_d, i, hist_t_rpdf_d[i]);
    }

    fprintf(stdout, "green pdf:\n");
    for (int_4 i=0; i<hist_nbins_d; i++) {
      fprintf(stdout, "%ld %ld: %f\n", hist_grnp_d, i, hist_t_gpdf_d[i]);
    }

    fprintf(stdout, "blue pdf:\n");
    for (int_4 i=0; i<hist_nbins_d; i++) {
      fprintf(stdout, "%ld %ld: %f\n", hist_blup_d, i, hist_t_bpdf_d[i]);
    }
  }
  
  // compute the sbe
  //
  if (hist_compare_cc(sbe_a) == ISIP_FALSE) {
    error_handler_cc((char_1*)"hist_test_cc",
  	     (char_1*)"error while computing the sbe");
    return ISIP_FALSE;
  }
  
  // exit gracefully
  //
  return ISIP_TRUE;
}
