// file: $USFS/class/image_analysis/v1.0/imaga_hist_04.cc
//

// isip include files
//
#include "image_analysis.h"
#include <integral_constants.h>

// method: hist_compare_cc
//
// arguments:
//  float_8& sbe_a: (output) sbe value
//
// return: a logical_1 value indicating status
//
// this method computes an sbe from two histograms.
//
logical_1 Image_analysis::hist_compare_cc(float_8& sbe_a) {
  
  // declare local variables
  //
  float_8 sum_r = (float_8)0.0;
  float_8 sum_g = (float_8)0.0;
  float_8 sum_b = (float_8)0.0;
  float_8 frac_r = (float_8)0.0;
  float_8 frac_g = (float_8)0.0;
  float_8 frac_b = (float_8)0.0;
  float_8 prod_r = (float_8)0.0;
  float_8 prod_g = (float_8)0.0;
  float_8 prod_b = (float_8)0.0;

  // compute the constant for the base 2 logarithm
  //
  float_8 scale = 1 / log(2);
  
  // compare the data from the model file with the computed data
  //
  for (int_4 i = 0; i < hist_nbins_d; i++) {
    
    // compute the relative entropy
    //
    if (hist_r_rpdf_d[i] != 0) {
      if (hist_t_rpdf_d[i] != 0) {
	frac_r = hist_t_rpdf_d[i] / hist_r_rpdf_d[i];
	prod_r = hist_t_rpdf_d[i] * log(frac_r) * scale;
	sum_r += prod_r;
      }
    }
    
    if (hist_r_gpdf_d[i] != 0) {
      if (hist_t_rpdf_d[i] != 0) {
	frac_g = hist_t_gpdf_d[i] / hist_r_gpdf_d[i];
	prod_g = hist_t_gpdf_d[i] * log(frac_g) * scale;
	sum_g += prod_g;
      }
    }
    
    if (hist_r_bpdf_d[i] != 0) {
      if (hist_t_bpdf_d[i] != 0) {
	frac_b = hist_t_bpdf_d[i] / hist_r_bpdf_d[i];
	prod_b = hist_t_bpdf_d[i] * log(frac_b) * scale;
	sum_b += prod_b;
      }
    }
  }

  // print the individual entropies of red, green and blue
  //
  fprintf (stdout, "%3.3f\t%3.3f\t%3.3f\t", sum_r, sum_g, sum_b);
  
  // weight the contributions from each color
  //
  float_8 rms_scaled = hist_rwgt_d * sum_r + hist_gwgt_d * sum_g +
    hist_bwgt_d * sum_b;
  
  if (debug_level_d > ISIP_DEBUG_DETAILED) {
    fprintf(stdout,"<%s> rms error = %f: (r) %f (g) %f (b) %f\n",
	    "Image_analysis::hist_compare_cc",
	    rms_scaled, sum_r, sum_g, sum_b);
  }
  
  // compute the scaled sbe
  //
  sbe_a = hist_ascale_d * rms_scaled + hist_bscale_d;
  
  if (debug_level_d > ISIP_DEBUG_BRIEF) {
    fprintf(stdout,"<%s> sbe = %f\n",
	    "Image_analysis::hist_compare_cc", sbe_a);
  }
  
  // exit gracefully
  //
  return ISIP_TRUE;
}


