// file: $USFS/util/analyze_image/v1.0/ai_gfls_0.cc
//

// isip include files
//
#include "analyze_image.h"
#include <ppm.h>

#include <integral_constants.h>

// method: get_next_filename_cc
//
// arguments:
//   char_1* fname_a: (output) next filename (space must be allocated
//				by calling program)
//   int_4 argc_a: (input) number of arguments
//   char_1* argv_a: (input) arguments 
//   int_4& pos_a: (input/output) current position in the argv stream
//
// return: a logical_1 value indicating the number of lines
//
// this method returns a filename one at a time
//
logical_1 get_next_filename_cc(char_1* fname_a, int_4 argc_a,
			       char** argv_a, int_4& pos_a) {
  
  // define global variables
  //
  static FILE* fp;
  static logical_1 flag = ISIP_FALSE;
  
  // declare a dummy object
  //
  Ppm ppm;
  
  // declare local variables
  //
  char_1 temp_buf[ISIP_MAX_STRING_LENGTH];
  int_4 m = 1;
  
  // check if pos is less than the number of arguments
  //
  if (pos_a < argc_a) {
    
    // expanding the filename
    //
    if (ppm.expand_cc(temp_buf, (char_1*)argv_a[pos_a]) == ISIP_FALSE) {
      fprintf(stdout, "%s: error in expanding the filename\n", argv_a[pos_a]);
    }
    
    // check if file is ppm
    //
    if (ppm.is_ppm_cc(temp_buf) == ISIP_TRUE) {
      strcpy((char*)fname_a, (char*)temp_buf);
      m = 0;
      pos_a++;
    }
    
    // if not ppm check if it is a file containing list of ppm files
    //
    else {
      
      // check the flag to open the file for the first time
      //
      if (flag == ISIP_FALSE) { 
	fp = fopen((char*)temp_buf, "r");
      }
      
      // check for the end of the file
      //
      if (fgets((char*)temp_buf, ISIP_MAX_STRING_LENGTH, fp) != (char*)NULL) {
	
	// cut off the newline char
	//
	temp_buf[strlen((char*)temp_buf)-1] = ISIP_NULL;
	
	// check for a comment line and/or blank line
	//
	char_1 nonwhitespace[2];
	
	if ((temp_buf[0] != ISIP_POUND) &&
	    (sscanf((char*)temp_buf, "%1s", nonwhitespace) > (int)0)) {
	  
	  strcpy((char*)fname_a, (char*)temp_buf);
	  flag = ISIP_TRUE;
	}
      }
      
      // if end of the line close the file and increment the argument
      //
      else {
	flag = ISIP_FALSE;
	fclose(fp);
	pos_a++;
      }
    }
  }
  
  // to return ISIP_FALSE after reading the arguments
  //
  if ((pos_a == argc_a) && (m == (int)1)) {
    pos_a++;
  }
  
  // return status
  //
  if (pos_a > argc_a) {
    return ISIP_FALSE;
  }
  else {
    return ISIP_TRUE;
  }
}






