// file: $USFS/util/analyze_image/v1.0/analyze_image.cc
//

// isip include files
//
#include "analyze_image.h"
#include "image_analysis.h"
#include "ppm.h"

#include "analyze_image_constants.h"
#include <integral_constants.h>

// main program
//
main(int argc, char** argv) {
  
  // declare command line arguments
  //
  char_1* param_file = (char_1*)NULL;
  char_1* output_file = (char_1*)NULL;
  
  // declare a debug parameter
  //
  int_4 debug_level = ISIP_DEBUG_NONE;
  
  // declare the position of the first file in the command line list
  //
  int_4 pos=0;
  
  // parse the command line
  //
  if (get_parameters_cc(param_file, output_file, debug_level, pos,
			argc, argv) == ISIP_FALSE) {
    fprintf(stdout, "%s: error in command line arguments\n", argv[0]);
    return ISIP_ERROR;
  }
  
  // check the arguments
  //
  FILE* fp_o = (FILE*)NULL;
  
  if (param_file == (char_1*)NULL) {
    fprintf(stdout, "%s: no parameter file\n", argv[0]);
    return ISIP_ERROR;
  }
  else {
    
    // prepare an output file if necessary
    //
    if (output_file != (char_1*)NULL) {
      fp_o = fopen((char*)output_file, "w");
      if (fp_o == (FILE*)NULL) {
	fprintf(stdout, "%s: error opening output file\n", argv[0]);
	return ISIP_ERROR;
      }
    }
    
    // print the param_file in standard output
    //
    fprintf(stdout, AI_PRINT_FORMAT_B, param_file);

    // print the information of the arguments in the output file, if any
    //
    if (fp_o != (FILE*)NULL) {
      fprintf(fp_o, AI_PRINT_FORMAT_B, param_file);
      fprintf(fp_o, AI_PRINT_FORMAT_C, output_file);
      fprintf(stdout, AI_PRINT_FORMAT_C, output_file);
    }
  }     
  
  // declare objects and the necessary variables
  // 
  Image_analysis ia[AI_MAX_NUMBER_MODELS];
  Ppm ppm;
  char_1** model_files = (char_1**)NULL;
  int_4 num_models = 0;
  
  // fetch the model filenames as a list
  //
  if (ia[(int)0].get_nmods_cc(num_models, model_files, param_file)
      == ISIP_FALSE) {
    fprintf(stdout, "error in reading the parameter files\n");
  }
  
  // load the model files
  //
  for (int i=0; i<num_models; i++) {
    ia[i].load_cc(model_files[i]);
  }
  
  // define counter to keep up with the number of files processed successfully
  //
  int_4 counter_before = (int_4)0;
  int_4 counter_after = (int_4)0;
  
  // declare the memory for the image_file
  //
  char_1 image_file[ISIP_MAX_STRING_LENGTH];
  
  // initialize only if the mode is train
  //
  if (ia[(int)0].init_cc() == ISIP_FALSE) {
    fprintf(stdout, "error initializing the data\n");
  }
  
  // printing the results (this part is temporary will be deleted later
  //
  fprintf(stdout, "\t\t\t%s\t\t\t\t\t\t", "filename");

  // this is for the edge detection algorithm
  //
  //fprintf(stdout, "max_line\tpercent_long\tpercent_short\n");

  fprintf(stdout, "%s", "sbe_value");

  // fetching the imagefile name and looping through all the images
  //
  while (get_next_filename_cc(image_file, argc, argv, pos)
	 == ISIP_TRUE) {
    
    // initializing the sbe
    //
    float_8 sbe = (float_8)0.0;
    
    // process the file
    //
    // loop over the models
    //
    counter_before++;
    
    for (int m=0; m<num_models; m++) {
      
      if (m == (int)0) {
	
	if (ia[m].set_debug_cc(debug_level) == ISIP_FALSE) {
	  fprintf(stdout, "%s:invalid debug level\n", argv[0]);
	}
	fprintf(stdout, "\n%s\t", image_file);
      }
      
      if (ia[m].process_cc(sbe, image_file) == ISIP_TRUE) {
	if (m == (int)0) {
	  counter_after++;
	}
	fprintf(stdout, "%f", sbe);
      }
    }
  }
  
  // write to the model file if the mode is train
  //
  if (ia[(int)0].write_cc() == ISIP_FALSE) {
    fprintf(stdout, "error writing the model file");
  }
  
  // close files
  //
  if (fp_o != (FILE*)NULL) {
    fclose(fp_o);
  }
  
  // print (to stdout only) how many successful files were processed
  //
  fprintf(stdout, "\n<%s: %ld of %ld files processed successfully>\n",
	  argv[0], counter_after, counter_before);
  
  // delete allocated memory
  //
  delete [] model_files;
   
  // exit gracefully
  //
  return ISIP_NO_ERROR;
}





